#
# spec file for package ghc-persistent
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name persistent
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.10.5.2
Release:        bp153.1.19
Summary:        Type-safe, multi-backend data serialization
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-fast-logger-devel
BuildRequires:  ghc-http-api-data-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-path-pieces-devel
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-silently-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/persistent>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Thu Feb 27 2020 psimons@suse.com
- Update persistent to version 2.10.5.2.
  [#]# 2.10.5.2
  * [#1041](https://github.com/yesodweb/persistent/pull/1041)
  * Explicit foreign keys can now reference tables with custom sql name
  * Add qualified names to the stock classes list.
* Fri Feb  7 2020 psimons@suse.com
- Update persistent to version 2.10.5.1.
  [#]# 2.10.5.1
  * [#1024](https://github.com/yesodweb/persistent/pull/1024)
  * Add the ability to do documentation comments in entity definition syntax. Unfortunately, TemplateHaskell cannot add documentation comments, so this can't be used to add Haddocks to entities.
  * Add Haddock explainers for some of the supported entity syntax in `Database.Persist.Quasi`
* Wed Jan 29 2020 psimons@suse.com
- Update persistent to version 2.10.5.
  [#]# 2.10.5
  * Add the `EntityWithPrefix` type to allow users to specify a custom prefix for raw SQL queries. [#1018](https://github.com/yesodweb/persistent/pull/1018)
  * Added Acquire based API to `Database.Persist.Sql` for working with
    connections/pools in monads which aren't MonadUnliftIO. [#984](https://github.com/yesodweb/persistent/pull/984)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Oct 31 2019 psimons@suse.com
- Update persistent to version 2.10.4.
  [#]# 2.10.4
  * Log exceptions when closing a connection fails. See point 1 in [yesod #1635](https://github.com/yesodweb/yesod/issues/1635#issuecomment-547300856). [#978](https://github.com/yesodweb/persistent/pull/978)
* Tue Oct 29 2019 psimons@suse.com
- Update persistent to version 2.10.3.
  [#]# 2.10.3
  * Added support for GHC 8.8 about MonadFail changes [#976](https://github.com/yesodweb/persistent/pull/976)
* Thu Oct 24 2019 psimons@suse.com
- Update persistent to version 2.10.2.
  [#]# 2.10.2
  * Added `runMigrationQuiet` and `runMigrationUnsafeQuiet` to `Database.Persist.Sql.Migration` as safer alternatives to `runMigrationSilent`. [#971](https://github.com/yesodweb/persistent/pull/971)
    This functions as workaround/fix for: [#966](https://github.com/yesodweb/persistent/issues/966), [#948](https://github.com/yesodweb/persistent/issues/948), [#640](https://github.com/yesodweb/persistent/issues/640), and [#474](https://github.com/yesodweb/persistent/issues/474)
  * Added RawSql instances for 9, 10, 11 and 12-column results. [#961](https://github.com/yesodweb/persistent/pull/961)
* Fri Aug  9 2019 psimons@suse.com
- Update persistent to version 2.10.1.
  [#]# 2.10.1
  * Added `constraint=` attribute to allow users to specify foreign reference constraint names.
* Thu Apr 18 2019 psimons@suse.com
- Update persistent to version 2.10.0.
  [#]# 2.10.0
  * Added two type classes `OnlyOneUniqueKey` and `AtLeastOneUniqueKey`. These classes are used as constraints on functions that expect a certain amount of unique keys. They are defined automatically as part of the `persistent-template`'s generation. [#885](https://github.com/yesodweb/persistent/pull/885)
  * Add the `entityComments` field to the `EntityDef` datatype, and `fieldComments` fields to the `FieldDef` datatype. The QuasiQuoter does not currently know how to add documentation comments to these types, but it can be expanded later. [#865](https://github.com/yesodweb/persistent/pull/865)
  * Expose the `SqlReadT` and `SqlWriteT` constructors. [#887](https://github.com/yesodweb/persistent/pull/887)
  * Remove deprecated `Connection` type synonym. Please use `SqlBackend` instead. [#894](https://github.com/yesodweb/persistent/pull/894)
  * Remove deprecated `SqlPersist` type synonym. Please use `SqlPersistT` instead. [#894](https://github.com/yesodweb/persistent/pull/894)
  * Alter the type of `connUpsertSql` to take a list of unique definitions. This paves the way for more efficient upsert implementations. [#895](https://github.com/yesodweb/persistent/pull/895)
* Mon Apr  8 2019 psimons@suse.com
- Update persistent to version 2.9.2.
  [#]# 2.9.2
  * Add documentation for the `Migration` type and some helpers. [#860](https://github.com/yesodweb/persistent/pull/860)
* Fri Jan 18 2019 psimons@suse.com
- Update persistent to version 2.9.1.
  [#]# 2.9.1
  * Fix [#847](https://github.com/yesodweb/persistent/issues/847): SQL error with `putMany` on Sqlite when Entity has no unique index.
* Sun Dec  2 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support http-api-data 0.4.x.
* Mon Oct 15 2018 psimons@suse.com
- Update persistent to version 2.9.0.
  [#] Changelog for persistent
  [#]# 2.9.0
  * Added support for SQL isolation levels to via SqlBackend. [#812]
  * Move `Database.Persist.Sql.Raw.QQ` to a separate `persistent-qq` package [#827](https://github.com/yesodweb/persistent/issues/827)
  * Fix [832](https://github.com/yesodweb/persistent/issues/832): `repsertMany` now matches `mapM_ (uncurry repsert)` and is atomic for supported sql back-ends.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update persistent to version 2.8.2 revision 1.
  * Added support for `sql=` to the unique constraints quasi-quoter so that users can specify the database names of the constraints.
  * DRY-ed up and exposed several util functions in `Database.Persist.Sql.Util`.
  * Upstream-ed `updatePersistValue`, `mkUpdateText`, and `commaSeparated` from `Database.Persist.MySQL`.
  * De-duplicated `updatePersistValue` from various `Database.Persist.Sql.Orphan.*` modules.
  * Batching enhancements to reduce db round-trips.
  * Added `getMany` and `repsertMany` for batched `get` and `repsert`.
  * Added `putMany` with a default/slow implementation. SqlBackend's that support native UPSERT should override this for batching enhancements.
  * Updated `insertEntityMany` to replace slow looped usage with batched execution.
  * See [#770](https://github.com/yesodweb/persistent/pull/770)
  * Switch from `MonadBaseControl` to `MonadUnliftIO`
  * Reapplies [#723](https://github.com/yesodweb/persistent/pull/723), which was reverted in version 2.7.3.
  * Improve error messages when failing to parse database results into Persistent records. [#741](https://github.com/yesodweb/persistent/pull/741)
  * A handful of `fromPersistField` implementations called `error` instead of returning a `Left Text`. All of the implementations were changed to return `Left`. [#741](https://github.com/yesodweb/persistent/pull/741)
  * Improve error message when a SQL insert fails with a custom primary key [#757](https://github.com/yesodweb/persistent/pull/757)
  * Reverts [#723](https://github.com/yesodweb/persistent/pull/723), which generalized functions using the `BackendCompatible` class. These changes were an accidental breaking change.
  * Recommend the `PersistDbSpecific` docs if someone gets an error about converting from `PersistDbSpecific`
  * Many of the functions have been generalized using the `BackendCompatible` class. [#723](https://github.com/yesodweb/persistent/pull/723)
  * This change was an accidental breaking change and was reverted in 2.7.3.
  * These change will be released in a future version of Persistent with a major version bump.
  * Add raw sql quasi quoters [#717](https://github.com/yesodweb/persistent/pull/717)
  * Added an `insertUniqueEntity` function [#718](https://github.com/yesodweb/persistent/pull/718)
  * Added `BackendCompatible` class [#701](https://github.com/yesodweb/persistent/pull/701)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 2.7.0.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 2.6.1 with cabal2obs.
* Fri Sep 30 2016 psimons@suse.com
- Update to version 2.6 revision 2 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 2.6 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.2.4.1 revision 0 with cabal2obs.
* Thu Mar 10 2016 mimi.vx@gmail.com
- update to 2.2.4.1
* Thu Dec 17 2015 mimi.vx@gmail.com
- update to 2.2.4
  * Workaround for side-exiting transformers in runSqlConn
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 2.2.3
  * PersistField instance for Natural
  * better oracle support in odbc
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
